@@ -1,6 +1,6 @@
 test_that("not_available() works", {
   expect_error(get_not_available(), NA)
-  expect_error(get_not_available("foo"))
+  expect_error(get_not_available("foo"), class = "getNotAvailableError")
 
   val <- struct(NA, "foo")
   set_not_available("foo", val)
@@ -13,7 +13,7 @@ test_that("not_available() works", {
 
   set_not_available("foo", NULL)
   set_not_available("foo_fun", function() NULL)
-  expect_error(get_not_available("foo_fun"))
+  expect_error(get_not_available("foo_fun"), class = "getNotAvailableTypeError")
 
   # reset list
   options(mark.na_list = NULL)
